<template>
    <div class="land-assets">
        <PublicTitle :iconUrl="require('@/assets/img/publicTitle/icon-土地.png')" title="土地资产" routerPath="/platLayout/LandLedger"/>
        <div class="top-statistics">
            <div class="item">
                <div class="label-unit">土地面积(亩)</div>
                <div class="value">{{ areaInfo.landArea }}</div>
                <div class="pending-value">
                    账面净值<span class="red-span">{{ areaInfo.bookValue }}</span>
                </div>
            </div>
            <div class="item">
                <div class="label-unit">闲置面积(亩)</div>
                <div class="value">{{ areaInfo[2023] }}</div>
                <div class="pending-value">
                    较去年
                    <template v-if=" areaInfo.decreaseRate &&areaInfo.decreaseRate.indexOf('-')===-1">
                       <span class="red-span">{{ areaInfo.decreaseRate }}</span><img
                        src="@/assets/img/publicTitle/icon-上升.png" alt="" />
                    </template>
                    <template v-else>
                       <span class="green-span">{{ areaInfo.decreaseRate }}</span><img
                        src="@/assets/img/publicTitle/icon-下降.png" alt="" />
                    </template>
                    
                   
                </div>
            </div>
        </div>
        <div class="bottom-chart">
            <div id="land-chart"></div>
            <div class="legend-content">
                <div class="legend-item" v-for="(item, index) in echartsData" :key="index">
                    <div class="item-icon" :style="{ background: colorList[index] }"></div>
                    <div class="item-label">{{ item.name }}</div>
                    <div class="item-value">{{ item.value }}</div>
                </div>
            </div>
        </div>
    </div>
</template>

<script>
import * as echarts from 'echarts'
import utils from '@/utils.js'
import api from '@/api/homePage.js'
import PublicTitle from '@/components/PublicTitle/index'
export default {
    name: 'LandAssets', // 土地资产
    components: { PublicTitle },
    data() {
        return {
            colorList: ['#55edb0', '#00d4ff', '#c679e5', '#198cff'],
            dataList: [
            ],
            echartsData: [],
            areaInfo: {}
        }
    },
    created() {
        this.getLand()
    },
    mounted() {
    },
    methods: {
        getLand() {
            api.landStatistics({}, res => {
                if (res.state) {
                    this.areaInfo = res.value.areaInfo
                    this.dataList = res.value.bookValueInfo
                }
                this.initChat()
            })
        },
        //字典翻译
        getDictName(code, value) {
            return utils.getDictName(code, value)
        },
        initChat() {
            this.echartsData = []
            this.dataList.forEach((e, index) => {
                this.echartsData.push({
                    name: this.getDictName('zczt', e.loadStatus),
                    value: e.landArea,
                    itemStyle: {
                        color: this.colorList[index]
                    }
                })
            });
            let chartDom = echarts.init(document.getElementById('land-chart'))
            let option = {
                tooltip: {
                    trigger: 'item',
                },
                // legend: {
                //     top: '5%',
                //     left: 'center',
                // },
                series: [
                    {
                        name: '面积',
                        type: 'pie',
                        radius: ['55%', '67%'],
                        center: ['47.6%', '48.4%'],
                        avoidLabelOverlap: false,
                        itemStyle: {
                            borderColor: '#fff',
                            borderWidth: 2,
                        },
                        label: {
                            show: false,
                            position: 'center',
                        },

                        emphasis: {
                            label: {
                                show: true,
                                fontSize: 30,
                                formatter: function (params) {
                                    return [
                                        '{num|' +
                                        params.value +
                                        '}' +
                                        '{unit|亩}',
                                        '{label|' + params.name + '}',
                                    ].join('\n')
                                },
                                rich: {
                                    num: {
                                        fontSize: 30,
                                        color: '#000',
                                        lineHeight: 30,
                                        fontWeight: 700,
                                    },
                                    unit: {
                                        fontSize: 14,
                                        color: '#111',
                                        lineHeight: 30,
                                        padding: [0, 5],
                                    },
                                    label: {
                                        fontSize: 20,
                                        lineHeight: 30,
                                        color: '#444',
                                    },
                                },
                            },
                        },
                        labelLine: {
                            show: false,
                        },
                        data: this.echartsData
                    },
                    // 外圈背景
                    {
                        type: 'pie',
                        radius: ['50%', '50%'],
                        center: ['47.6%', '48.4%'],
                        hoverAnimation: false,
                        clockWise: false,
                        cursor: 'default',
                        itemStyle: {
                            normal: {
                                borderWidth: 2,
                                borderColor: '#eaeaea',
                            },
                        },
                        tooltip: {
                            show: false,
                        },
                        label: {
                            show: false,
                        },
                        data: [100],
                    },
                    {
                        type: 'gauge',
                        radius: '98%',
                        center: ['47.6%', '48.4%'],
                        clockwise: true,
                        startAngle: '100',
                        endAngle: '-269.9999',
                        splitNumber: 200, //线的条数
                        pointer: {
                            show: false,
                        },
                        axisLine: {
                            show: false,
                        },
                        axisTick: {
                            show: false,
                        },
                        tooltip: {
                            show: false,
                        },
                        splitLine: {
                            show: true,
                            length: 15,
                            lineStyle: {
                                color: '#eaeaea',
                                width: 1,
                            },
                        },
                        axisLabel: {
                            show: false,
                        },
                    },
                    {
                        type: 'gauge',
                        radius: '83.5%',
                        center: ['47.6%', '48.4%'],
                        clockwise: true,
                        startAngle: '100',
                        endAngle: '-269.9999',
                        splitNumber: 140, //线的条数
                        pointer: {
                            show: false,
                        },
                        axisLine: {
                            show: false,
                        },
                        axisTick: {
                            show: false,
                        },
                        tooltip: {
                            show: false,
                        },
                        splitLine: {
                            show: true,
                            length: 1,
                            lineStyle: {
                                color: '#eaeaea',
                                width: 2,
                            },
                        },
                        axisLabel: {
                            show: false,
                        },
                    },

                ],
            }
            console.log(option);
            chartDom.setOption(option)
            window.addEventListener('resize', () => {
                chartDom.resize()
            })
            handleChartLoop(option, chartDom);
            // 饼图自动轮播
            function handleChartLoop(option, myChart) {
                if (!myChart) {
                    return
                }
                let currentIndex = 0 // 当前高亮图形在饼图数据中的下标
                highlightPie()
                // 取消所有高亮并高亮当前图形
                function highlightPie() {
                    // 遍历饼图数据，取消所有图形的高亮效果
                    for (var idx in option.series[0].data) {
                        myChart.dispatchAction({
                            type: 'downplay',
                            seriesIndex: 0,
                            dataIndex: idx
                        })
                    }
                    // 高亮当前图形
                    myChart.dispatchAction({
                        type: 'highlight',
                        seriesIndex: 0,
                        dataIndex: currentIndex
                    })
                }
                // // 用户鼠标悬浮到某一图形时，停止自动切换并高亮鼠标悬浮的图形
                myChart.on('mouseover', (params) => {
                    if (params.componentType == 'graphic') {
                        return
                    }
                    currentIndex = params.dataIndex
                    highlightPie()
                })
            }
        },
    },
}
</script>

<style scoped lang="scss">
.land-assets {
    width: 100%;
    height: 100%;
    padding: 16px;
    box-sizing: border-box;
    background: #ffffff;
    box-shadow: 4px 4px 10px 0px rgba(53, 152, 220, 0.1);
    border-radius: 16px 16px 16px 16px;

    .top-statistics {
        display: flex;
        justify-content: space-between;
        margin-top: 5px;

        .item {
            box-sizing: border-box;
            width: 48.5%;
            height: 119px;
            padding: 16px 8px;
            background: linear-gradient(180deg,
                    #e5f1ff 0%,
                    rgba(255, 255, 255, 0) 100%);
            border-radius: 8px 8px 8px 8px;
            border: 1px solid;
            border-image: linear-gradient(180deg,
                    rgba(255, 255, 255, 0),
                    rgba(229.49999392032623, 240.73427349328995, 255, 1)) 1 1;

            .label-unit {
                font-size: 16px;
                color: #7a8899;
            }

            .value {
                margin-top: 8px;
                height: 34px;
                font-size: 26px;
                font-weight: 700;
                color: #0f2a4d;
                border-bottom: 1px solid #e2eaf3;
            }

            .pending-value {
                font-size: 14px;
                color: #7a8899;
                margin-top: 11px;

                span {
                    font-size: 14px;
                    color: #0f2a4d;
                }

                img {
                    width: 14px;
                    height: 14px;
                    vertical-align: text-top;
                }

                .red-span {
                    color: #e54552;
                }
                .green-span{
                    color: green;
                }
            }
        }
    }

    .bottom-chart {
        width: 100%;
        height: 320px;
        // background: url('~@/assets/img/饼图bg.png') no-repeat;
        // background-size: 280px;
        // background-position: 15px 15px;
        display: flex;

        #land-chart {
            width: 60%;
            height: 100%;
        }

        .legend-content {
            box-sizing: border-box;
            padding: 40px 0 40px 10px;
            width: 40%;
            height: 100%;
            display: flex;
            flex-direction: column;
            justify-content: space-evenly;

            .legend-item {
                border-bottom: 1px solid #d9d9d9;
                display: flex;
                align-items: flex-end;
                padding: 0 0 15px 0;

                .item-icon {
                    width: 8px;
                    height: 8px;
                    border-radius: 50%;
                    margin: 0 0 5px 0;
                }

                .item-label {
                    font-size: 16px;
                    color: #0f2a4d;
                    margin-left: 6px;
                }

                .item-value {
                    font-size: 16px;
                    font-weight: 700;
                    margin-left: 25px;
                    color: #0f2a4d;
                }
            }
        }
    }
}
</style>
